package	jp.co.sds_corp.util.daemon.file;

import java.io.File;
import java.util.regex.Pattern;

import jp.co.sds_corp.util.config.IConfiguration;

/**
* 正規表現を使用したファイル名フィルタです。
<P>
{@link #init}で使用されるXMLは以下の形式です。
<PRE>
&lt;Filter class="jp.co.sds_corp.util.daemon.file.RegexpFilenameFilter"&gt;
	&lt;pattern&gt;.*&lt;/pattern&gt;
&lt;/Filter&gt;
</PRE>
*/
public class RegexpFilenameFilter implements IFilenameFilter
{
	String pattern;
	Pattern ptn;

	/**
	* 設定情報から正規表現のパターンを取得し、初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		setPattern( config.get( "pattern" ));
	}

	/**
	* パターンを設定します。
	* @param	pattern	パターン
	*/
	public void setPattern( String pattern ) {
		this.pattern = pattern;
		ptn = Pattern.compile( pattern );
	}

	/**
	* パターンを取得します。
	* @return	パターン
	*/
	public String getPattern() {
		return pattern;
	}

	/**
	* 指定されたファイルをファイルリストに含めるかどうかをテストします。
	* @param	path	ファイルが見つかったディレクトリ
	* @param	name	ファイルの名前
	*/
	public boolean accept( File path, String name ) {
		boolean bRet = ptn.matcher( name ).matches();
		return bRet;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "class", getClass().getName() );
		config.addChild( "pattern", pattern );
	}

	/**
	* このファイル名フィルタの文字列表現を返します。
	* @return	このファイル名フィルタの文字列表現
	*/
	public String toString() {
		return getClass().getName() + ":" + pattern;
	}
}
