package	jp.co.sds_corp.util.daemon.filter;

import jp.co.sds_corp.util.config.IConfiguration;

/**
* イベントのフィルタリングを行なうオブジェクトの基底クラスです。
*/
public abstract class AbstractFilter implements IFilter
{
	Type	type;

	/**
	* 設定情報でフィルタを初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		IConfiguration attr = config.getAttributes();
		String var;
		var = attr.get( "type" );
		if ( var != null && var.equals( "allow" )) {
			type = Type.ALLOW; 
		} else
		if ( var != null && var.equals( "deny" )) {
			type = Type.DENY;
		} else {
			throw( new IllegalArgumentException( "illegal type:" + var ));
		}
	}

	/**
	* 設定されている内容を保存します。
	* @param    config  設定情報
	*/  
	public void saveConfig( IConfiguration config ) {
		if ( type == Type.ALLOW ) {
			config.setAttribute( "type", "allow" );
		} else {
			config.setAttribute( "type", "deny" );
		}
	}

	/**
	* このフィルタの文字列表現を返します。
	* @return	文字列表現
	*/
	public String toString() {
		String ret = getClass().getName();
		switch ( type ) {
		case ALLOW: ret += "(ALLOW)"; break;
		case DENY: ret += "(DENY)"; break;
		default: ret += "(UNKNOWN)";
		}
		return ret;
	}

	/**
	* 処理の可否を設定ます。
	* @see		IFilter.Type#ALLOW
	* @see		IFilter.Type#DENY
	* @param	var		処理の可否
	*/
	public void setType( Type var ) {
		type = var;
	}

	/**
	* 時間内の処理の可否を返します。
	* @see		IFilter.Type#ALLOW
	* @see		IFilter.Type#DENY
	* @return	処理の可否
	*/
	public Type getType() {
		return type;
	}

}

