package	jp.co.sds_corp.util.daemon.remote.rmi;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.remote.AbstractServer;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* デーモンマネージャのRMI I/F のサーバです。
<pre>
&lt;Remote type="RMI"&gt;
	&lt;host&gt;localhost&lt;/host&gt;
	&lt;port&gt;2011&lt;/port&gt;
	&lt;name&gt;DaemonManager&lt;/name&gt;
	&lt;CreateRegistry&gt;true&lt;/CreateRegistry&gt;
&lt;/Remote&gt;
</pre>
*/
public class RMIServer extends AbstractServer
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	String	host;
	int		nPort;
	String	regName;
	RMICommander	cmd;
	DaemonRemoteImpl	controller;

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		setType( "RMI" );
		host = config.get( "host" );
		nPort = Integer.valueOf( config.get( "port" )).intValue();
		regName = config.get( "name" );
		boolean bCr = true;
		String create = config.get( "CreateRegistry", "false" );
		if ( create != null && create.equals( "false" )) {
			bCr = false;
		}
		logger.debug( this, "start RMIServer "
						+ "rmi://" + host + ":" + nPort + "/" + regName
						+ " create=" + bCr );

		cmd = new RMICommander( getManager() );
		controller = new DaemonRemoteImpl( cmd, host, nPort, regName, bCr );
		controller.setDebug( isDebug());
	}

	/**
	* RMIサーバを終了します。
	*/
	public void exit() {
		try {
			logger.debug( this, "unbind "
						+ "rmi://" + host + ":" + nPort + "/" + regName );
			controller.unbind( regName );
		} catch ( Exception ex ) {
			logger.error( this, "unbind error", ex );
		}
	}

}
